# Table of Contents

- [fact-sheet-fields](<./fact-sheet-fields.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Fact Sheet Fields](<./Fact-Sheet-Fields.md>)
  - [Overview](<./Fact-Sheet-Fields/Overview.md>)
  - [Configuring Fields](<./Fact-Sheet-Fields/Configuring-Fields.md>)
  - [Field Types](<./Fact-Sheet-Fields/Field-Types.md>)
  - [Field Width](<./Fact-Sheet-Fields/Field-Width.md>)
  - [Adding a Custom Field](<./Fact-Sheet-Fields/Adding-a-Custom-Field.md>)
  - [Deleting Fields and Field Values](<./Fact-Sheet-Fields/Deleting-Fields-and-Field-Values.md>)
  - [Showing Fields in Views](<./Fact-Sheet-Fields/Showing-Fields-in-Views.md>)
  - [Showing Fields in Filters](<./Fact-Sheet-Fields/Showing-Fields-in-Filters.md>)
  - [Setting Fields as Read-Only](<./Fact-Sheet-Fields/Setting-Fields-as-Read-Only.md>)
  - [Enabling Search for Custom String Fields](<./Fact-Sheet-Fields/Enabling-Search-for-Custom-String-Fields.md>)
  - [Internal Fields](<./Fact-Sheet-Fields/Internal-Fields.md>)
  - [External ID Field](<./Fact-Sheet-Fields/External-ID-Field.md>)
  - [Unused Fields](<./Fact-Sheet-Fields/Unused-Fields.md>)
  - [Was this page helpful?](<./Fact-Sheet-Fields/Was-this-page-helpful.md>)
